@@ -18,108 +18,102 @@ package tektonconfig
 
 import (
 	"context"
-	"fmt"
-
-	"github.com/go-logr/zapr"
-	mfc "github.com/manifestival/client-go-client"
-	"github.com/tektoncd/operator/pkg/reconciler/openshift/tektonpipeline"
-	"go.uber.org/zap"
-	"knative.dev/pkg/injection"
+	"os"
 
 	mf "github.com/manifestival/manifestival"
 	"github.com/tektoncd/operator/pkg/apis/operator/v1alpha1"
 	"github.com/tektoncd/operator/pkg/client/clientset/versioned"
 	operatorclient "github.com/tektoncd/operator/pkg/client/injection/client"
 	"github.com/tektoncd/operator/pkg/reconciler/common"
-	"github.com/tektoncd/operator/pkg/reconciler/openshift/tektonaddon"
 	"github.com/tektoncd/operator/pkg/reconciler/openshift/tektonconfig/extension"
+	openshiftPipeline "github.com/tektoncd/operator/pkg/reconciler/openshift/tektonpipeline"
+	openshiftTrigger "github.com/tektoncd/operator/pkg/reconciler/openshift/tektontrigger"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
 	kubeclient "knative.dev/pkg/client/injection/kube/client"
-	"knative.dev/pkg/logging"
+)
+
+const (
+	versionKey = "VERSION"
 )
 
 func OpenShiftExtension(ctx context.Context) common.Extension {
-
-	logger := logging.FromContext(ctx)
-	mfclient, err := mfc.NewClient(injection.GetConfig(ctx))
-	if err != nil {
-		logger.Fatalw("error creating client from injected config", zap.Error(err))
-	}
-	mflogger := zapr.NewLogger(logger.Named("manifestival").Desugar())
-	manifest, err := mf.ManifestFrom(mf.Slice{}, mf.UseClient(mfclient), mf.UseLogger(mflogger))
-	if err != nil {
-		logger.Fatalw("error creating initial manifest", zap.Error(err))
-	}
-	ext := openshiftExtension{
+	return openshiftExtension{
 		operatorClientSet: operatorclient.Get(ctx),
 		kubeClientSet:     kubeclient.Get(ctx),
-		manifest:          manifest,
 	}
-
-	return ext
 }
 
 type openshiftExtension struct {
 	operatorClientSet versioned.Interface
 	kubeClientSet     kubernetes.Interface
-	manifest          mf.Manifest
 }
 
 func (oe openshiftExtension) Transformers(comp v1alpha1.TektonComponent) []mf.Transformer {
 	return []mf.Transformer{}
 }
 func (oe openshiftExtension) PreReconcile(ctx context.Context, tc v1alpha1.TektonComponent) error {
-	configInstance := tc.(*v1alpha1.TektonConfig)
-
-	pipelineUpdated, err := common.ValidateParamsAndSetDefault(ctx,
-		&configInstance.Spec.Pipeline.Params,
-		tektonpipeline.PipelineParams,
-		func(params *[]v1alpha1.Param) error { return nil })
-	if err != nil {
-		return err
-	}
-
-	// If profile is all then validates the passed addon params and
-	// add the missing params with their default values
-	var addonUpdated = false
-	if configInstance.Spec.Profile == common.ProfileAll {
-		addonUpdated, err = common.ValidateParamsAndSetDefault(ctx, &configInstance.Spec.Addon.Params, tektonaddon.AddonParams,
-			tektonaddon.ValidateParamsConditions())
-		if err != nil {
-			return err
-		}
-	}
-
-	if pipelineUpdated || addonUpdated {
-		_, err := oe.operatorClientSet.OperatorV1alpha1().TektonConfigs().Update(ctx, configInstance, metav1.UpdateOptions{})
-		if err != nil {
-			return err
-		}
-		// Returning error just to make reconcile it again so that further code gets updated TektonConfig
-		return fmt.Errorf("reconcile")
-	}
 
+	config := tc.(*v1alpha1.TektonConfig)
 	r := rbac{
 		kubeClientSet:     oe.kubeClientSet,
 		operatorClientSet: oe.operatorClientSet,
-		manifest:          oe.manifest,
-		ownerRef:          configOwnerRef(tc),
+		version:           os.Getenv(versionKey),
+		tektonConfig:      config,
 	}
-	return r.createResources(ctx)
+
+	// set openshift specific defaults
+	openshiftPipeline.SetDefault(&config.Spec.Pipeline)
+	openshiftTrigger.SetDefault(&config.Spec.Trigger.TriggersProperties)
+	r.setDefault()
+
+	createRBACResource := true
+	for _, v := range config.Spec.Params {
+		// check for param name and if its matches to createRbacResource
+		// then disable auto creation of RBAC resources by deleting installerSet
+		if v.Name == rbacParamName && v.Value == "false" {
+			createRBACResource = false
+			if err := deleteInstallerSet(ctx, r.operatorClientSet, r.tektonConfig, componentNameRBAC); err != nil {
+				return err
+			}
+			// remove openshift-pipelines.tekton.dev/namespace-reconcile-version label from namespaces while deleting RBAC resources.
+			if err := r.cleanUp(ctx); err != nil {
+				return err
+			}
+		}
+	}
+
+	// TODO: Remove this after v0.55.0 release, by following a depreciation notice
+	// --------------------
+	if err := r.cleanUpRBACNameChange(ctx); err != nil {
+		return err
+	}
+	// --------------------
+
+	if createRBACResource {
+		return r.createResources(ctx)
+	}
+	return nil
 }
+
 func (oe openshiftExtension) PostReconcile(ctx context.Context, comp v1alpha1.TektonComponent) error {
 	configInstance := comp.(*v1alpha1.TektonConfig)
-	if configInstance.Spec.Profile == common.ProfileAll {
+
+	if configInstance.Spec.Profile == v1alpha1.ProfileAll {
 		if err := extension.CreateAddonCR(comp, oe.operatorClientSet.OperatorV1alpha1()); err != nil {
 			return err
 		}
 	}
+
+	if configInstance.Spec.Profile == v1alpha1.ProfileBasic || configInstance.Spec.Profile == v1alpha1.ProfileLite {
+		return extension.TektonAddonCRDelete(oe.operatorClientSet.OperatorV1alpha1().TektonAddons(), common.AddonResourceName)
+	}
+
 	return nil
 }
 func (oe openshiftExtension) Finalize(ctx context.Context, comp v1alpha1.TektonComponent) error {
 	configInstance := comp.(*v1alpha1.TektonConfig)
-	if configInstance.Spec.Profile == common.ProfileAll {
+	if configInstance.Spec.Profile == v1alpha1.ProfileAll {
 		if err := extension.TektonAddonCRDelete(oe.operatorClientSet.OperatorV1alpha1().TektonAddons(), common.AddonResourceName); err != nil {
 			return err
 		}
@@ -127,11 +121,12 @@ func (oe openshiftExtension) Finalize(ctx context.Context, comp v1alpha1.TektonC
 
 	r := rbac{
 		kubeClientSet: oe.kubeClientSet,
+		version:       os.Getenv(versionKey),
 	}
 	return r.cleanUp(ctx)
 }
 
 // configOwnerRef returns owner reference pointing to passed instance
-func configOwnerRef(tc v1alpha1.TektonComponent) metav1.OwnerReference {
-	return *metav1.NewControllerRef(tc, tc.GroupVersionKind())
+func configOwnerRef(tc v1alpha1.TektonInstallerSet) metav1.OwnerReference {
+	return *metav1.NewControllerRef(&tc, tc.GetGroupVersionKind())
 }
